==> pyabaqus-1.0.3-py2.py3-none-any.whl: abaqus/DisplayGroup/LeafFromElementVarRange.py <==
from abaqusConstants import *
from .Leaf import Leaf


class LeafFromElementVarRange(Leaf):
    """The LeafFromElementVarRange object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects 
    are constructed as temporary objects, which are then used as arguments to DisplayGroup 
    commands. 
    The LeafFromElementVarRange object is derived from the Leaf object. 

    Access
    ------
        - import displayGroupOdbToolset

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------

    """

    # A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF, 
    # DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES. 
    leafType: SymbolicConstant = None

    def __init__(self, minimumRange: float = None, maximumRange: float = 3, insideRange: Boolean = ON):
        """This method creates a Leaf object from elements with values lying in a variable range.

        Path
        ----
            - LeafFromElementVarRange

        Parameters
        ----------
        minimumRange
            A Float specifying the minimum value for the variable range. The default value is 
            −3.40282346639E38. 
        maximumRange
            A Float specifying the maximum value for the variable range. The default value is 
            3.40282346639e+038. 
        insideRange
            A Boolean specifying the method used to evaluate the range. If *insideRange*=ON, the 
            range falls inside the specified minimum and maximum values. The default value is ON. 

        Returns
        -------
            A LeafFromElementVarRange object. 

        Exceptions
        ----------
            None. 
        """
        super().__init__(DEFAULT_MODEL)
        pass

==> pyabaqus-1.0.10-py2.py3-none-any.whl: abaqus/DisplayGroup/LeafFromElementVarRange.py <==
from abaqusConstants import *
from .Leaf import Leaf


class LeafFromElementVarRange(Leaf):
    """The LeafFromElementVarRange object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects 
    are constructed as temporary objects, which are then used as arguments to DisplayGroup 
    commands. 
    The LeafFromElementVarRange object is derived from the Leaf object. 

    Access
    ------
        - import displayGroupOdbToolset

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------

    """

    # A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF, 
    # DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES. 
    leafType: SymbolicConstant = None

    def __init__(self, minimumRange: float = None, maximumRange: float = 3, insideRange: Boolean = ON):
        """This method creates a Leaf object from elements with values lying in a variable range.

        Path
        ----
            - LeafFromElementVarRange

        Parameters
        ----------
        minimumRange
            A Float specifying the minimum value for the variable range. The default value is 
            −3.40282346639E38. 
        maximumRange
            A Float specifying the maximum value for the variable range. The default value is 
            3.40282346639e+038. 
        insideRange
            A Boolean specifying the method used to evaluate the range. If *insideRange*=ON, the 
            range falls inside the specified minimum and maximum values. The default value is ON. 

        Returns
        -------
            A LeafFromElementVarRange object. . 
        """
        super().__init__(DEFAULT_MODEL)
        pass
